@@ -296,14 +296,14 @@ def update_stock_PRS_day():
 def update_stock_PRS_new():
     stock_RS_OH_MA_new()
     stock_select_PRS_new()
-    pass
+    
 
 if __name__ == '__main__':
     # new -- date , time 
     # day -- trade_date 
     # TODO
     update_stock_PRS_day()
-    update_stock_PRS_new()
+    #update_stock_PRS_new()
     #print(is_trade_time_secs_cn())
-    pass
+    
 
