@@ -1,4 +1,5 @@
 # coding: utf-8
+
 import requests
 import json
 import time
@@ -7,11 +8,14 @@ import pandas as pd
 from rrshare.rqUtil import rq_util_get_last_tradedate, rq_util_if_trade, rq_util_if_tradetime, rq_util_date_today
 
 class Swsindex(object):
-    """http://www.swsindex.com/idx0120.aspx?columnid=8832#
+    """
+    swl1_realtime :
+    http://www.swsindex.com/idx0120.aspx?columnid=8832#
     industry class:
     http://www.swsindex.com/downloadfiles.aspx?swindexcode=SwClass&type=530&columnid=8892
 
     get sw industry index class and realtime quote from swsindex.com by post method.
+    swl2 reltime spot: http://www.swsindex.com/idx0120.aspx?columnId=8833
     """
     
     def __init__(self):
@@ -40,8 +44,8 @@ class Swsindex(object):
             'key': 'L1',
             'p': '{}'.format(i),
             'where': "L1 in('801010','801030','801040','801050','801080','801110','801120','801130','801140', \
-                       '801150','801160','801170','801180','801200','801210','801230','801710','801720','801730',\
-                            '801740','801750','801760','801770','801780','801790','801880','801890')",
+                        '801150','801160','801170','801180','801200','801210','801230','801710','801720','801730', \
+                            '801740','801750','801760','801770','801780','801790','801880','801890','801950','801960','801970','801980')",
             'orderby': '',
             'fieldlist': 'L1,L2,L3,L4,L5,L6,L7,L8,L11',
             'pagecount': '31',
