@@ -36,9 +36,11 @@ class SwlIndexStock(object):
 
     
     def fetch_swl_index(self,level=""):
-        df_tspro = pro.index_classify(level=level,src='SW')
+        df_tspro = pro.index_classify(level=level,src='SW2021')   #update
         df_tspro['index'] = df_tspro['index_code'].map(lambda x: x[:6])
         df_tspro['name_level'] = df_tspro['industry_name'] + "_" + df_tspro['level']
+        print("get_swl_index")
+        time.sleep(10)
         return df_tspro
 
 
@@ -132,18 +134,18 @@ def save_stock_belong_swsindex():
     PgsqlClass().insert_to_psql(df_sws, 'rrshare','stock_belong_swl1',if_exists='replace')
 
 
-
-
 def rq_save_swl_industry_list_stock_belong():
     swl =  SwlIndexStock()
     swl.save_swl_list()
+    time.sleep(20)
     swl.save_swl_contains_stock()
+    time.sleep(20)
     swl.save_stock_belong_swl_L()
+    time.sleep(20)
     swl.save_stock_belong_swl_all()
+    time.sleep(20)
     save_stock_belong_swsindex()
     
-    
-
 
 if __name__ == '__main__':
     #li = SwlIndexStock()
@@ -161,5 +163,3 @@ if __name__ == '__main__':
     rq_save_swl_industry_list_stock_belong()
     pass
 
-    
-
