@@ -352,13 +352,12 @@ def rq_save_stock_bar_hfq_pg(start_date='19900101'): #20050101i#TODO
 
 
 if __name__ == '__main__':          
-    
     rq_save_stock_list_pg()
-    #rq_save_swl_day_pg('20200101')
+    #rq_save_swl_day_pg('20200101') TODO
 
     #储存日线数据  包含ts_pro中"daily" "daily_basic" "adj_factor"所有内容 
     #由于采用日期对比机制进行储存，可以增量储存之前数据
-    #rq_save_stock_day_pg('20180101')  #rq_save_stock_day_pg('20180101')储存起始日期
-    #rq_save_stock_day_adj_fillna_pg('20200101')
+    #rq_save_stock_day_pg('20180101')储存起始日期
+    rq_save_stock_day_adj_fillna_pg('20200101')
         
-    pass
+    
