@@ -59,8 +59,6 @@ from rrshare.rqUtil.rqLogs import (rq_util_log_debug, rq_util_log_expection,
 
 # postgres
 from rrshare.rqUtil.rqPgsql import (PgsqlClass,client_pgsql, read_data_from_pg,read_sql_from_pg,read_table_from_pg,read_unique_data_from_pg,save_data_to_postgresql)
-# mysql
-from rrshare.rqUtil.rqMysql import (conn_mysqldb, mysql_engine, write_to_mysql,read_mysql_sql, read_mysql_table,read_mysql_select)
 
 # Parameter
 from rrshare.rqUtil.rqParameter import (
